## Summary

Note: This document is currently under development. It will contain the following elements.

## Short summary

- explanation
- goals
- dimensions
- differences between disciplines

For the data extraction, risk-of-bias assessment, and meta-analysis, established software packages like [RevMan](https://training.cochrane.org/online-learning/core-software/revman) are recommended.

For the analysis, R packages are recommended.


## References

Harrer, M., Cuijpers, P., Furukawa, T.A., & Ebert, D.D. (2021). Doing Meta-Analysis with R: A Hands-On Guide. Boca Raton, FL and London: Chapman & Hall/CRC Press. ISBN 978-0-367-61007-4. [link](https://bookdown.org/MathiasHarrer/Doing_Meta_Analysis_in_R/)

<!--

## Steps and operations

### Problem formulation

### Metadata retrieval

### Metadata prescreen

### PDF retrieval

### PDF screen

### Data extraction and synthesis

- For manuscript development see separate page for Word/Tex/Md, Reference Managers

## Software recommendations

-->
